@@ -275,7 +275,7 @@ class StreamApp(object):
         # set actor 变量参数
         params = self.get_actor_params(actor_json)
         print("actor_json>>>>"+json.dumps(actor_json))
-        print("params>>>>"+json.dumps(params))
+        print("params>>>>"+str(params))
         self.actor.args = params
         # TODO get_set_param,get_set_runtime_param
         input_ports = self.get_actor_input_ports(actor_json)
